  ##########################
  #### function is.Gram ####
  ##########################


is.Gram <- function(x){
	return(inherits(x,"Gram"))
	}